<?php

declare(strict_types=1);

namespace Drupal\lb_plus\EventSubscriber;

use Drupal\lb_plus\LbPlusEntityHelperTrait;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityDisplayRepositoryInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\navigation_plus\Event\EditableUiBuilder as EditableUiBuilderEvent;

final class EditableUiBuilder implements EventSubscriberInterface {

  use LbPlusEntityHelperTrait;

  public function __construct(
    protected EntityDisplayRepositoryInterface $entityDisplayRepository,
    protected ConfigFactoryInterface $configFactory,
  ) {}

  public function onUiBuild(EditableUiBuilderEvent $event): void {
    if ($event->getMode() !== 'edit') {
      return;
    }
    $entity = $event->getEntity();
    $view_mode = $event->getViewMode();
    $display = $this->entityDisplayRepository->getViewDisplay($entity->getEntityTypeId(), $entity->bundle(), $view_mode);
    if (empty($view_display)) {
      $view_mode = 'default';
      $display = $this->entityDisplayRepository->getViewDisplay($entity->getEntityTypeId(), $entity->bundle(), $view_mode);
    }

    if ($display && $display->getThirdPartySetting('layout_builder', 'enabled', FALSE)) {
      $section_storage = $this->getSectionStorageForEntity($entity, $view_mode);
      if ($section_storage) {
        $build = $event->getBuild();
        // Override the node build with the layout builder UI.
        $field_names = array_keys($entity->getFieldDefinitions());
        $build = array_diff_key($build, array_flip($field_names));
        unset($build['_layout_builder']);
        $build['layout'] = [
          '#type' => 'layout_builder_plus',
          '#section_storage' => $section_storage,
        ];
        $event->setBuild($build);
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      EditableUiBuilderEvent::class => ['onUiBuild'],
    ];
  }

}
